@@ -16,7 +16,7 @@
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
-   version 3 of the License, or (at your option) any later version.
+   version 2 of the License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -119,15 +119,15 @@ extern "C" {
   id	_parent;
 }
 
-+ (NSString*) descriptionFromType: (int)type;
-+ (int) typeFromDescription: (NSString*)desc;
++ (NSString*) descriptionFromType: (NSInteger)type;
++ (NSInteger) typeFromDescription: (NSString*)desc;
 
 - (NSString*) href;
 
 - (void*) lib;
 - (GSXMLNamespace*) next;
 - (NSString*) prefix;
-- (int) type;
+- (NSInteger) type;
 - (NSString*) typeDescription;
 
 @end
@@ -140,8 +140,8 @@ extern "C" {
   id	_parent;
 }
 
-+ (NSString*) descriptionFromType: (int)type;
-+ (int) typeFromDescription: (NSString*)desc;
++ (NSString*) descriptionFromType: (NSInteger)type;
++ (NSInteger) typeFromDescription: (NSString*)desc;
 
 - (NSDictionary*) attributes;
 - (NSString*) content;
@@ -177,7 +177,7 @@ extern "C" {
 - (NSMutableDictionary*) propertiesAsDictionaryWithKeyTransformationSel:
   (SEL)keyTransformSel;
 - (void) setObject: (NSString*)value forKey:(NSString*)key;
-- (int) type;
+- (NSInteger) type;
 - (NSString*) typeDescription;
 - (void) setNamespace: (GSXMLNamespace *)space;
 
@@ -209,10 +209,10 @@ extern "C" {
 + (NSString*) xmlEncodingStringForStringEncoding: (NSStringEncoding)encoding;
 
 - (void) abortParsing;
-- (int) columnNumber;
+- (NSInteger) columnNumber;
 - (GSXMLDocument*) document;
 - (BOOL) doValidityChecking: (BOOL)yesno;
-- (int) errNo;
+- (NSInteger) errNo;
 - (BOOL) getWarnings: (BOOL)yesno;
 - (id) initWithSAXHandler: (GSSAXHandler*)handler;
 - (id) initWithSAXHandler: (GSSAXHandler*)handler
@@ -223,7 +223,7 @@ extern "C" {
 		 withData: (NSData*)data;
 
 - (BOOL) keepBlanks: (BOOL)yesno;
-- (int) lineNumber;
+- (NSInteger) lineNumber;
 - (NSString*) messages;
 - (BOOL) parse;
 - (BOOL) parse: (NSData*)data;
@@ -256,8 +256,8 @@ extern "C" {
 /** <override-dummy /> */
 - (void) attributeDecl: (NSString*)nameElement
                   name: (NSString*)name
-                  type: (int)type
-          typeDefValue: (int)defType
+                  type: (NSInteger)type
+          typeDefValue: (NSInteger)defType
           defaultValue: (NSString*)value;
 /** <override-dummy /> */
 - (void) characters: (NSString*)name;
@@ -267,7 +267,7 @@ extern "C" {
 - (void) comment: (NSString*) value;
 /** <override-dummy /> */
 - (void) elementDecl: (NSString*)name
-		type: (int)type;
+		type: (NSInteger)type;
 /** <override-dummy /> */
 - (void) endDocument;
 /** <override-dummy /> */
@@ -278,35 +278,35 @@ extern "C" {
 	       href: (NSString*)href;
 /** <override-dummy /> */
 - (void) entityDecl: (NSString*)name
-               type: (int)type
+               type: (NSInteger)type
              public: (NSString*)publicId
              system: (NSString*)systemId
             content: (NSString*)content;
 - (void) error: (NSString*)e;
 - (void) error: (NSString*)e
-     colNumber: (int)colNumber
-    lineNumber: (int)lineNumber;
+     colNumber: (NSInteger)colNumber
+    lineNumber: (NSInteger)lineNumber;
 - (BOOL) externalSubset: (NSString*)name
              externalID: (NSString*)externalID
                systemID: (NSString*)systemID;
 - (void) fatalError: (NSString*)e;
 - (void) fatalError: (NSString*)e
-          colNumber: (int)colNumber
-         lineNumber: (int)lineNumber;
+          colNumber: (NSInteger)colNumber
+         lineNumber: (NSInteger)lineNumber;
 - (void*) getEntity: (NSString*)name;
 - (void*) getParameterEntity: (NSString*)name;
 /** <override-dummy /> */
 - (void) globalNamespace: (NSString*)name
 		    href: (NSString*)href
 		  prefix: (NSString*)prefix;
-- (int) hasExternalSubset;
-- (int) hasInternalSubset;
+- (NSInteger) hasExternalSubset;
+- (NSInteger) hasInternalSubset;
 /** <override-dummy /> */
 - (void) ignoreWhitespace: (NSString*)ch;
 - (BOOL) internalSubset: (NSString*)name
              externalID: (NSString*)externalID
                systemID: (NSString*)systemID;
-- (int) isStandalone;
+- (NSInteger) isStandalone;
 - (NSString*) loadEntity: (NSString*)publicId
 		      at: (NSString*)location;
 /** <override-dummy /> */
@@ -331,7 +331,8 @@ extern "C" {
 - (void) startElement: (NSString*)elementName
 	       prefix: (NSString*)prefix
 		 href: (NSString*)href
-           attributes: (NSMutableDictionary*)elementAttributes;
+           attributes: (NSMutableDictionary*)elementAttributes
+           namespaces: (NSMutableDictionary*)elementNamespaces;
 /** <override-dummy /> */
 - (void) unparsedEntityDecl: (NSString*)name
 		     public: (NSString*)publicId
@@ -339,8 +340,8 @@ extern "C" {
 	       notationName: (NSString*)notation;
 - (void) warning: (NSString*)e;
 - (void) warning: (NSString*)e
-       colNumber: (int)colNumber
-      lineNumber: (int)lineNumber;
+       colNumber: (NSInteger)colNumber
+      lineNumber: (NSInteger)lineNumber;
 
 @end
 
@@ -363,6 +364,20 @@ extern "C" {
  * GSXPathString *result = [p evaluateExpression: @"string(/body/text())"];
  * NSLog (@"Got %@", [result stringValue]);
  *
+ * If the XML document contains namespaces, you first need to register them
+ * with the parser by using registerNamespaceWithPrefix:href:, as in:
+ *
+ * GSXPathContext *p = [[GSXPathContext alloc] initWithDocument: document];
+ * if ([p registerNamespaceWithPrefix: @"a"  href="http://www.gnustep.org/demo"] == NO)
+ *  {
+ *    // Error registering namespace, do something about it.
+ *  }
+ *
+ * and then you can use the namespace prefix in your expressions, as in
+ *
+ * GSXPathString *result = [p evaluateExpression: @"string(/a:body/text())"];
+ * NSLog (@"Got %@", [result stringValue]);
+ *
  */
 @interface GSXPathContext : NSObject
 {
@@ -371,6 +386,12 @@ extern "C" {
 }
 - (id) initWithDocument: (GSXMLDocument*)d;
 - (GSXPathObject*) evaluateExpression: (NSString*)XPathExpression;
+
+/*
+ * Registers a new namespace.  Return YES if succesful, NO if not.
+ */
+- (BOOL) registerNamespaceWithPrefix: (NSString *)prefix
+                                href: (NSString *)href;
 @end
 
 /** XPath queries return a GSXPathObject.  GSXPathObject in itself is
@@ -411,11 +432,11 @@ extern "C" {
  * For XPath queries returning a node set.
  */
 @interface GSXPathNodeSet : GSXPathObject
-- (unsigned int) count;
-- (unsigned int) length;
+- (NSUInteger) count;
+- (NSUInteger) length;
 
 /** Please note that index starts from 0.  */
-- (GSXMLNode *) nodeAtIndex: (unsigned)index;
+- (GSXMLNode *) nodeAtIndex: (NSUInteger)index;
 @end
 
 @interface GSXMLDocument (XSLT)
@@ -442,6 +463,7 @@ extern "C" {
 
 
 #include	<Foundation/NSURLHandle.h>
+#include	<Foundation/NSURLConnection.h>
 
 @class	NSArray;
 @class	NSDictionary;
@@ -504,13 +526,10 @@ extern "C" {
 @interface	GSXMLRPC : NSObject <NSURLHandleClient>
 {
 @private
-#ifdef GNUSTEP
   NSURLHandle		*handle;
-#else
   NSString		*connectionURL;
   NSURLConnection	*connection;
   NSMutableData		*response;
-#endif
   NSTimer		*timer;
   id			result;
   id			delegate;	// Not retained.
@@ -552,7 +571,8 @@ extern "C" {
  * as a string.<br />
  * This method is intended for use by applications acting as XMLRPC servers.
  */
-- (NSString*) buildResponseWithFaultCode: (int)code andString: (NSString*)s;
+- (NSString*) buildResponseWithFaultCode: (NSInteger)code
+                               andString: (NSString*)s;
 
 /**
  * Builds an XMLRPC response with the specified array of parameters and
@@ -605,7 +625,7 @@ extern "C" {
  */
 - (id) makeMethodCall: (NSString*)method
 	       params: (NSArray*)params
-	      timeout: (int)seconds;
+	      timeout: (NSInteger)seconds;
 
 /**
  * Parses XML data containing an XMLRPC method call.<br />
@@ -629,7 +649,7 @@ extern "C" {
  * Raises an exception if parsing fails.<br />
  * Used internally when making a method call to a remote server.
  */
-- (NSDictionary*) parseResponse: (NSData*)response
+- (NSDictionary*) parseResponse: (NSData*)resp
 			 params: (NSMutableArray*)params;
 
 /**
@@ -662,7 +682,7 @@ extern "C" {
  */
 - (BOOL) sendMethodCall: (NSString*)method
 		 params: (NSArray*)params
-		timeout: (int)seconds;
+		timeout: (NSInteger)seconds;
 
 /**
  * Specify whether to generate compact XML (omit indentation and other white
