@@ -10,7 +10,7 @@
    This file is part of the GNUstep Base Library.
 
    This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
+   modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.
   
@@ -19,16 +19,22 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.
   
-   You should have received a copy of the GNU Library General Public
+   You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free
-   Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
+   Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02111 USA.
   */
 
 #ifndef __NSBundle_h_GNUSTEP_BASE_INCLUDE
 #define __NSBundle_h_GNUSTEP_BASE_INCLUDE
+#import	<GNUstepBase/GSVersionMacros.h>
 
-#include <Foundation/NSObject.h>
-#include <Foundation/NSString.h>
+#if	defined(__cplusplus)
+extern "C" {
+#endif
+
+#import	<Foundation/NSObject.h>
+#import	<Foundation/NSString.h>
 
 @class NSString;
 @class NSArray;
@@ -36,6 +42,15 @@
 @class NSMutableArray;
 @class NSMutableDictionary;
 
+#if OS_API_VERSION(100500,GS_API_LATEST) 
+enum {
+  NSBundleExecutableArchitectureI386      = 0x00000007,
+  NSBundleExecutableArchitecturePPC       = 0x00000012,
+  NSBundleExecutableArchitecturePPC64     = 0x01000012,
+  NSBundleExecutableArchitectureX86_64    = 0x01000007,
+};
+#endif
+
 /**
  *  Notification posted when a bundle is loaded.  The notification object is
  *  the [NSBundle] itself.  The notification also contains a <em>userInfo</em>
@@ -256,8 +271,8 @@ GS_EXPORT NSString* const NSLoadedClasses;
    the bundle.
    </p>
    <p>
-   If ext is nil or empty, then the first file with name and any
-   extension is returned.
+   If ext is nil or empty, then the first file exactly matching name
+   (ie with no extension) is returned.
    </p>
 */
 - (NSString*) pathForResource: (NSString*)name
@@ -301,7 +316,7 @@ GS_EXPORT NSString* const NSLoadedClasses;
 /** Set the bundle version */
 - (void) setBundleVersion: (unsigned)version;
 
-#ifndef STRICT_OPENSTEP
+#if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 /**
  *  Returns subarray of given array containing those localizations that are
  *  used to locate resources given environment and user preferences.
@@ -316,22 +331,28 @@ GS_EXPORT NSString* const NSLoadedClasses;
 + (NSArray *) preferredLocalizationsFromArray: (NSArray *)localizationsArray 
 			       forPreferences: (NSArray *)preferencesArray;
 
+#if OS_API_VERSION(100200,GS_API_LATEST) 
 /**
  * Returns a boolean indicating whether code for the bundle has been loaded.
  */
 - (BOOL) isLoaded;
+#endif
 
 /**
-   This method returns the same information as
-   -pathsForResourcesOfType:inDirectory: except that only non-localized
-   resources and resources that match the localization localizationName
-   are returned.
+ * This method returns the same information as
+ * -pathsForResourcesOfType:inDirectory: except that only non-localized
+ * resources and resources that match the localization localizationName
+ * are returned.<br />
+ * The GNUstep implementation places localised resources in the array
+ * before any non-localised resources.
  */
 - (NSArray*) pathsForResourcesOfType: (NSString*)extension
 			 inDirectory: (NSString*)subPath
 		     forLocalization: (NSString*)localizationName;
 /**
- *  Not implemented.
+ * This is like -pathForResource:ofType:inDirectory: but returns only
+ * resources matching localizationName (preferentially), or non-localized
+ * resources.
  */
 - (NSString*) pathForResource: (NSString*)name
 		       ofType: (NSString*)ext
@@ -341,19 +362,30 @@ GS_EXPORT NSString* const NSLoadedClasses;
 /** Returns the info property list associated with the bundle. */
 - (NSDictionary*) infoDictionary;
 
+#if OS_API_VERSION(100200,GS_API_LATEST) 
 /** Returns a localized info property list based on the preferred
-    localization or the most appropriate localization if the preferred
-    one cannot be found.
-*/
-- (NSDictionary *)localizedInfoDictionary;
+ *  localization or the most appropriate localization if the preferred
+ *  one cannot be found.
+ */
+- (NSDictionary*) localizedInfoDictionary;
+
+/** Not implemented
+ */
+- (NSString*) developmentLocalization;
+
+/** Not implemented
+ */
+- (id) objectForInfoDictionaryKey: (NSString *)key;
+#endif
 
 /** Returns all the localizations in the bundle. */
-- (NSArray *)localizations;
+- (NSArray*) localizations;
 
-/** Returns the list of localizations that the bundle uses to search
-    for information. This is based on the user's preferences.
-*/
-- (NSArray *)preferredLocalizations;
+/**
+ * Returns the list of localizations that the bundle uses to search
+ * for information. This is based on the user's preferences.
+ */
+- (NSArray*) preferredLocalizations;
 
 /** Loads any executable code contained in the bundle into the
     application. Load will be called implicitly if any information
@@ -362,27 +394,72 @@ GS_EXPORT NSString* const NSLoadedClasses;
  */
 - (BOOL) load;
 
-/** Returns the path to the executable code in the bundle */
-- (NSString *)executablePath;
+#if OS_API_VERSION(100200,GS_API_LATEST) 
+/** * Not implemented
+ */
+- (BOOL) unload;
 #endif
 
+/** Returns the path to the executable code in the bundle */
+- (NSString *) executablePath;
+#endif
+
+#if OS_API_VERSION(100500,GS_API_LATEST) 
+/** Not implemented */
+- (NSArray *) executableArchitectures;
+/** Not implemented */
+- (BOOL) preflightAndReturnError: (NSError **)error;
+/** Not implemented */
+- (BOOL) loadAndReturnError: (NSError **)error;
+#endif
 @end
 
-#ifndef	 NO_GNUSTEP
+#if GS_API_VERSION(GS_API_NONE, 011700)
 /**
  *  Augments [NSBundle], including methods for handling libraries in the GNUstep
  *  fashion, for rapid localization, and other purposes.
  */
 @interface NSBundle (GNUstep)
 
-/** This method is an experimental GNUstep extension, and
- *  might change.  At the moment, search on the standard GNUstep
- *  directories (starting from GNUSTEP_USER_ROOT, and going on to
- *  GNUSTEP_SYSTEM_ROOT) for a directory
- *  Libraries/Resources/'libraryName'/.
+/** This method is an experimental GNUstep extension, and might change.
+ * <p>Return a bundle to access the resources for the (static or shared) library
+ * libraryName, with interface version interfaceVersion.
+ * </p>
+ * <p>Resources for shared libraries are stored into
+ * GNUSTEP_LIBRARY/Libraries/libraryName/Versions/interfaceVersion/Resources/;
+ * this method will search for the first such existing directory and return it.
+ *</p>
+ * <p>libraryName should be the name of a library without the
+ * <em>lib</em> prefix or any extensions; interfaceVersion is the
+ * interface version of the library (eg, it's 1.13 in libgnustep-base.so.1.13; 
+ * see library.make on how to control it).
+ * </p>
+ * <p>This method exists to provide resource bundles for libraries and has no
+ * particular relationship to the library code itsself.  The named library
+ * could be a dynamic library linked in to the running program, a static
+ * library (whose code may not even exist on the host machine except where
+ * it is linked in to the program), or even a library which is not linked
+ * into the program at all (eg. where you want to share resources provided
+ * for a library you do not actually use).
+ * </p>
+ * <p>The bundle for the library <em>gnustep-base</em> is a special case ...
+ * for this bundle the -principalClass method returns [NSObject] and the
+ * -executablePath method returns the path to the gnustep-base dynamic
+ *  library (if it can be found).  As a general rule, library bundles are
+ *  not guaranteed to return values for these methods as the library may
+ *  not exist on disk.
+ * </p>
+ */
++ (NSBundle *) bundleForLibrary: (NSString *)libraryName
+                        version: (NSString *)interfaceVersion;
+
+/** This method is a equivalent to bundleForLibrary:version: with a nil
+ * version.
  */
 + (NSBundle *) bundleForLibrary: (NSString *)libraryName;
 
+
+
 /** Find a resource in the "Library" directory. */
 + (NSString*) pathForLibraryResource: (NSString*)name
 			      ofType: (NSString*)ext
@@ -390,13 +467,6 @@ GS_EXPORT NSString* const NSLoadedClasses;
 
 @end
 
-/** Warning - do not use this.  */
-#define GSLocalizedString(key, comment) \
-  [[NSBundle gnustepBundle] localizedStringForKey:(key) value:@"" table:nil]
-/** Warning - do not use this.  */
-#define GSLocalizedStringFromTable(key, tbl, comment) \
-  [[NSBundle gnustepBundle] localizedStringForKey:(key) value:@"" table:(tbl)]
-
 #endif /* GNUSTEP */
 
 /**
@@ -494,156 +564,9 @@ GS_EXPORT NSString* const NSLoadedClasses;
 #define NSLocalizedStringFromTableInBundle(key, tbl, bundle, comment) \
   [bundle localizedStringForKey:(key) value:@"" table:(tbl)]
 
-#ifndef	NO_GNUSTEP
-#define NSLocalizedStringFromTableInFramework(key, tbl, fpth, comment) \
-  [[NSBundle mainBundle] localizedStringForKey:(key) value:@"" \
-  table: [bundle pathForGNUstepResource:(tbl) ofType: nil inDirectory: (fpth)]
-#endif /* GNUSTEP */
 
-  /* Now Support for Quick Localization */
-#ifndef NO_GNUSTEP
-
-  /* The quickest possible way to localize a string:
-    
-     NSLog (_(@"New Game"));
-    
-     Please make use of the longer functions taking a comment when you
-     get the time to localize seriously your code.
-  */
-
-/**
- * <p>
- *   This function (macro) is a GNUstep extension.
- * </p>
- * <p>
- *   <code>_(@"My string to translate")</code>
- * </p>
- * <p>
- *   is exactly the same as
- * </p>
- * <p>
- *   <code>NSLocalizedString (@"My string to translate", @"")</code>
- * </p>
- * <p>
- *   It is useful when you need to translate an application
- *   very quickly, as you just need to enclose all strings
- *   inside <code>_()</code>.  But please note that when you
- *   use this macro, you are not taking advantage of comments
- *   for the translator, so consider using
- *   <code>NSLocalizedString</code> instead when you need a
- *   comment.
- * </p>
- */
-#define _(X) NSLocalizedString (X, @"")
- 
-  /* The quickest possible way to localize a static string:
-    
-     static NSString *string = __(@"New Game");
-    
-     NSLog (_(string)); */
- 
-/**
- * <p>
- *   This function (macro) is a GNUstep extension.
- * </p>
- * <p>
- *   <code>__(@"My string to translate")</code>
- * </p>
- * <p>
- *   is exactly the same as
- * </p>
- * <p>
- *   <code>NSLocalizedStaticString (@"My string to translate", @"")</code>
- * </p>
- * <p>
- *   It is useful when you need to translate an application very
- *   quickly.  You would use it as follows for static strings:
- * </p>
- * <p>
- *  <code>
- *    NSString *message = __(@"Hello there");
- 
- *    ... more code ...
- 
- *    NSLog (_(messages));
- *  </code>
- * </p>
- * <p>
- *   But please note that when you use this macro, you are not
- *   taking advantage of comments for the translator, so
- *   consider using <code>NSLocalizedStaticString</code>
- *   instead when you need a comment.
- * </p>
- */
-#define __(X) X
-
-  /* The better way for a static string, with a comment - use as follows -
-
-     static NSString *string = NSLocalizedStaticString (@"New Game",
-                                                        @"Menu Option");
-
-     NSLog (_(string));
-
-     If you need anything more complicated than this, please initialize
-     the static strings manually.
-*/
-
-/**
- * <p>
- *   This function (macro) is a GNUstep extensions, and it is used
- *   to localize static strings.  Here is an example of a static
- *   string:
- * </p>
- * <p>
- *   <code>
- *     NSString *message = @"Hi there";
- 
- *     ... some code ...
- 
- *     NSLog (message);
- *  </code>
- * </p>
- * <p>
- *   This string can not be localized using the standard
- *   openstep functions/macros.  By using this gnustep extension,
- *   you can localize it as follows:
- * </p>
- * <p>
- *   <code>
- *     NSString *message = NSLocalizedStaticString (@"Hi there",
- *       @"Greeting");
- * 
- *     ... some code ...
- * 
- *     NSLog (NSLocalizedString (message, @""));
- *  </code>
- * </p>
- * <p>
- *   When the tools generate the
- *   <code>Localizable.strings</code> file from the source
- *   code, they will ignore the <code>NSLocalizedString</code>
- *   call while they will extract the string (and the comment)
- *   to localize from the <code>NSLocalizedStaticString</code>
- *   call.
- * </p>
- * <p>
- *   When the code is compiled, instead, the
- *   <code>NSLocalizedStaticString</code> call is ignored (discarded,
- *   it is a macro which simply expands to <code>key</code>), while
- *   the <code>NSLocalizedString</code> will actually look up the
- *   string for translation in the <code>Localizable.strings</code>
- *   file.
- * </p>
- * <p>
- *   Please note that there is currently no macro/function to
- *   localize static strings using different tables.  If you
- *   need that functionality, you have either to prepare the
- *   localization tables by hand, or to rewrite your code in
- *   such a way as not to use static strings.
- * </p>
- */
-#define NSLocalizedStaticString(key, comment) key
-
-#endif /* NO_GNUSTEP */
+#if	defined(__cplusplus)
+}
+#endif
 
 #endif	/* __NSBundle_h_GNUSTEP_BASE_INCLUDE */
