@@ -11,7 +11,7 @@
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
-   version 3 of the License, or (at your option) any later version.
+   version 2 of the License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -282,9 +282,10 @@ GS_EXPORT BOOL NSDeallocateZombies;
  */
 #define NSDebugFLLog(level, format, args...) \
   do { if (GSDebugSet(level) == YES) { \
-    NSString *fmt = GSDebugFunctionMsg( \
-	__PRETTY_FUNCTION__, __FILE__, __LINE__, format); \
-    NSLog(fmt , ## args); }} while (0)
+    NSString *s = GSDebugFunctionMsg( \
+      __PRETTY_FUNCTION__, __FILE__, __LINE__, \
+      [NSString stringWithFormat: format, ##args]); \
+    NSLog(@"%@", s); }} while (0)
 
 /**
  * This macro is a shorthand for NSDebugFLLog() using then default debug
@@ -292,9 +293,10 @@ GS_EXPORT BOOL NSDeallocateZombies;
  */
 #define NSDebugFLog(format, args...) \
   do { if (GSDebugSet(@"dflt") == YES) { \
-    NSString *fmt = GSDebugFunctionMsg( \
-	__PRETTY_FUNCTION__, __FILE__, __LINE__, format); \
-    NSLog(fmt , ## args); }} while (0)
+    NSString *s = GSDebugFunctionMsg( \
+      __PRETTY_FUNCTION__, __FILE__, __LINE__, \
+      [NSString stringWithFormat: format, ##args]); \
+    NSLog(@"%@", s); }} while (0)
 
 /**
  * This macro is like NSDebugLLog() but includes the name and location
@@ -302,9 +304,10 @@ GS_EXPORT BOOL NSDeallocateZombies;
  */
 #define NSDebugMLLog(level, format, args...) \
   do { if (GSDebugSet(level) == YES) { \
-    NSString *fmt = GSDebugMethodMsg( \
-	self, _cmd, __FILE__, __LINE__, format); \
-    NSLog(fmt , ## args); }} while (0)
+    NSString *s = GSDebugFunctionMsg( \
+      __PRETTY_FUNCTION__, __FILE__, __LINE__, \
+      [NSString stringWithFormat: format, ##args]); \
+    NSLog(@"%@", s); }} while (0)
 
 /**
  * This macro is a shorthand for NSDebugMLLog() using then default debug
@@ -312,9 +315,10 @@ GS_EXPORT BOOL NSDeallocateZombies;
  */
 #define NSDebugMLog(format, args...) \
   do { if (GSDebugSet(@"dflt") == YES) { \
-    NSString *fmt = GSDebugMethodMsg( \
-	self, _cmd, __FILE__, __LINE__, format); \
-    NSLog(fmt , ## args); }} while (0)
+    NSString *s = GSDebugFunctionMsg( \
+      __PRETTY_FUNCTION__, __FILE__, __LINE__, \
+      [NSString stringWithFormat: format, ##args]); \
+    NSLog(@"%@", s); }} while (0)
 
 /**
  * This macro saves the name and location of the function in
@@ -361,10 +365,12 @@ GS_EXPORT BOOL NSDeallocateZombies;
  */
 #define GSOnceFLog(format, args...) \
   do { static BOOL beenHere = NO; if (beenHere == NO) {\
-    NSString *fmt = GSDebugFunctionMsg( \
-	__PRETTY_FUNCTION__, __FILE__, __LINE__, format); \
+    NSString *s = GSDebugFunctionMsg( \
+      __PRETTY_FUNCTION__, __FILE__, __LINE__, \
+      [NSString stringWithFormat: format, ##args]); \
     beenHere = YES; \
-    NSLog(fmt , ## args); }} while (0)
+    NSLog(@"%@", s); }} while (0)
+
 /**
  * Macro to log a message only the first time it is encountered.<br />
  * Not entirely thread safe ... but that's not really important,
@@ -377,10 +383,11 @@ GS_EXPORT BOOL NSDeallocateZombies;
  */
 #define GSOnceMLog(format, args...) \
   do { static BOOL beenHere = NO; if (beenHere == NO) {\
-    NSString *fmt = GSDebugMethodMsg( \
-	self, _cmd, __FILE__, __LINE__, format); \
+    NSString *s = GSDebugFunctionMsg( \
+      __PRETTY_FUNCTION__, __FILE__, __LINE__, \
+      [NSString stringWithFormat: format, ##args]); \
     beenHere = YES; \
-    NSLog(fmt , ## args); }} while (0)
+    NSLog(@"%@", s); }} while (0)
 
 
 
@@ -430,9 +437,10 @@ GS_EXPORT BOOL NSDeallocateZombies;
  */
 #define NSWarnFLog(format, args...) \
   do { if (GSDebugSet(@"NoWarn") == NO) { \
-    NSString *fmt = GSDebugFunctionMsg( \
-	__PRETTY_FUNCTION__, __FILE__, __LINE__, format); \
-    NSLog(fmt , ## args); }} while (0)
+    NSString *s = GSDebugFunctionMsg( \
+      __PRETTY_FUNCTION__, __FILE__, __LINE__, \
+      [NSString stringWithFormat: format, ##args]); \
+    NSLog(@"%@", s); }} while (0)
 
 /**
  * This macro is like NSWarnLog() but includes the name and location of the
@@ -440,9 +448,10 @@ GS_EXPORT BOOL NSDeallocateZombies;
  */
 #define NSWarnMLog(format, args...) \
   do { if (GSDebugSet(@"NoWarn") == NO) { \
-    NSString *fmt = GSDebugMethodMsg( \
-	self, _cmd, __FILE__, __LINE__, format); \
-    NSLog(fmt , ## args); }} while (0)
+    NSString *s = GSDebugFunctionMsg( \
+      __PRETTY_FUNCTION__, __FILE__, __LINE__, \
+      [NSString stringWithFormat: format, ##args]); \
+    NSLog(@"%@", s); }} while (0)
 #else
 #define NSWarnLog(format, args...)
 #define NSWarnFLog(format, args...)
@@ -453,19 +462,19 @@ GS_EXPORT BOOL NSDeallocateZombies;
  *  Retrieve stack information.  Use caution: uses built-in gcc functions
  *  and currently only works up to 100 frames.
  */
-GS_EXPORT void *NSFrameAddress(int offset);
+GS_EXPORT void *NSFrameAddress(NSUInteger offset);
 
 /**
  *  Retrieve stack information.  Use caution: uses built-in gcc functions
  *  and currently only works up to 100 frames.
  */
-GS_EXPORT void *NSReturnAddress(int offset);
+GS_EXPORT void *NSReturnAddress(NSUInteger offset);
 
 /**
  *  Retrieve stack information.  Use caution: uses built-in gcc functions
  *  and currently only works up to 100 frames.
  */
-GS_EXPORT unsigned NSCountFrames(void);
+GS_EXPORT NSUInteger NSCountFrames(void);
 
 #if	defined(__cplusplus)
 }
