@@ -7,7 +7,7 @@
    This file is part of the GNUstep Base Library.
 
    This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
+   modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.
    
@@ -16,23 +16,28 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.
    
-   You should have received a copy of the GNU Library General Public
+   You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free
-   Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
-   MA 02111 USA.
+   Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02111 USA.
   */ 
 
 #ifndef _NSDictionary_h_GNUSTEP_BASE_INCLUDE
 #define _NSDictionary_h_GNUSTEP_BASE_INCLUDE
+#import	<GNUstepBase/GSVersionMacros.h>
 
-#include <Foundation/NSObject.h>
+#import	<Foundation/NSObject.h>
+
+#if	defined(__cplusplus)
+extern "C" {
+#endif
 
 @class NSArray, NSString, NSEnumerator, NSURL;
 
 @interface NSDictionary : NSObject <NSCoding, NSCopying, NSMutableCopying>
 + (id) dictionary;
 + (id) dictionaryWithContentsOfFile: (NSString*)path;
-#ifndef	STRICT_OPENSTEP
+#if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 + (id) dictionaryWithContentsOfURL: (NSURL*)aURL;
 #endif
 + (id) dictionaryWithDictionary: (NSDictionary*)otherDictionary;
@@ -40,22 +45,22 @@
 + (id) dictionaryWithObjects: (NSArray*)objects forKeys: (NSArray*)keys;
 + (id) dictionaryWithObjects: (id*)objects
 		     forKeys: (id*)keys
-		       count: (unsigned)count;
+		       count: (NSUInteger)count;
 + (id) dictionaryWithObjectsAndKeys: (id)firstObject, ...;
 
 - (NSArray*) allKeys;
 - (NSArray*) allKeysForObject: (id)anObject;
 - (NSArray*) allValues;
-- (unsigned) count;						// Primitive
+- (NSUInteger) count;						// Primitive
 - (NSString*) description;
 - (NSString*) descriptionInStringsFileFormat;
 - (NSString*) descriptionWithLocale: (NSDictionary*)locale;
 - (NSString*) descriptionWithLocale: (NSDictionary*)locale
-			     indent: (unsigned int)level;
+			     indent: (NSUInteger)level;
 
 - (id) init;
 - (id) initWithContentsOfFile: (NSString*)path;
-#ifndef	STRICT_OPENSTEP
+#if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 - (id) initWithContentsOfURL: (NSURL*)aURL;
 #endif
 - (id) initWithDictionary: (NSDictionary*)otherDictionary;
@@ -64,7 +69,7 @@
 - (id) initWithObjectsAndKeys: (id)firstObject, ...;
 - (id) initWithObjects: (id*)objects
 	       forKeys: (id*)keys
-		 count: (unsigned)count;			// Primitive
+		 count: (NSUInteger)count;			// Primitive
 - (BOOL) isEqualToDictionary: (NSDictionary*)other;
 
 - (NSEnumerator*) keyEnumerator;				// Primitive
@@ -74,7 +79,7 @@
 - (NSArray*) objectsForKeys: (NSArray*)keys notFoundMarker: (id)marker;
 
 - (BOOL) writeToFile: (NSString*)path atomically: (BOOL)useAuxiliaryFile;
-#ifndef	STRICT_OPENSTEP
+#if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 - (id) valueForKey: (NSString*)key;
 - (BOOL) writeToURL: (NSURL*)url atomically: (BOOL)useAuxiliaryFile;
 #endif
@@ -82,20 +87,24 @@
 
 @interface NSMutableDictionary: NSDictionary
 
-+ (id) dictionaryWithCapacity: (unsigned)numItems;
++ (id) dictionaryWithCapacity: (NSUInteger)numItems;
 
 - (void) addEntriesFromDictionary: (NSDictionary*)otherDictionary;
-- (id) initWithCapacity: (unsigned)numItems;			// Primitive
+- (id) initWithCapacity: (NSUInteger)numItems;			// Primitive
 - (void) removeAllObjects;
 - (void) removeObjectForKey: (id)aKey;				// Primitive
 - (void) removeObjectsForKeys: (NSArray*)keyArray;
 - (void) setObject: (id)anObject forKey: (id)aKey;		// Primitive
 - (void) setDictionary: (NSDictionary*)otherDictionary;
-#ifndef	STRICT_OPENSTEP
+#if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 - (void) takeStoredValue: (id)value forKey: (NSString*)key;
 - (void) takeValue: (id)value forKey: (NSString*)key;
 - (void) setValue: (id)value forKey: (NSString*)key;
 #endif
 @end
 
+#if	defined(__cplusplus)
+}
+#endif
+
 #endif
