@@ -61,11 +61,11 @@ extern "C" {
  *	Accessing message elements.
  */
 - (void) getArgument: (void*)buffer
-	     atIndex: (int)index;
+	     atIndex: (NSInteger)index;
 - (void) getReturnValue: (void*)buffer;
 - (SEL) selector;
 - (void) setArgument: (void*)buffer
-	     atIndex: (int)index;
+	     atIndex: (NSInteger)index;
 - (void) setReturnValue: (void*)buffer;
 - (void) setSelector: (SEL)aSelector;
 - (void) setTarget: (id)anObject;
@@ -120,7 +120,6 @@ extern "C" {
 - (id) initWithArgframe: (arglist_t)frame selector: (SEL)aSelector;
 - (id) initWithMethodSignature: (NSMethodSignature*)aSignature;
 - (id) initWithSelector: (SEL)aSelector;
-- (id) initWithTarget: (id)anObject selector: (SEL)aSelector, ...;
 - (void*) returnFrame: (arglist_t)argFrame;
 @end
 
