@@ -11,7 +11,7 @@
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
-   version 3 of the License, or (at your option) any later version.
+   version 2 of the License, or (at your option) any later version.
    
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -141,7 +141,7 @@ enum {
  * <item>GSCygwinOperatingSystem - cygwin unix-like environment</item>
  * </list>
  */
-- (unsigned int) operatingSystem;
+- (NSUInteger) operatingSystem;
 
 /**
  * Return a human readable string representing the operating system type.<br />
@@ -189,9 +189,17 @@ enum {
  */
 - (void) setProcessName: (NSString*)newName;
 
+#if OS_API_VERSION(100500,GS_API_LATEST) 
+/** Not implemented */
+- (NSUInteger) processorCount;
+/** Not implemented */
+- (NSUInteger) activeProcessorCount;
+/** Not implemented */
+- (unsigned long long) physicalMemory;
+#endif
 @end
 
-#if OS_API_VERSION(GS_API_NONE,GS_API_NONE)
+#if GS_API_VERSION(GS_API_NONE,011700)
 
 /**
  * Provides GNUstep-specific methods for controlled debug logging (a GNUstep
@@ -235,7 +243,7 @@ enum {
  * auto-initialize it are working.<br />
  * It is also safe to call this method to override the effects
  * of the automatic initialisation, which some applications may need
- * to do when using GNUstep libraries embeddedm within other frameworks.
+ * to do when using GNUstep libraries embedded within other frameworks.
  */
 + (void) initializeWithArguments: (char**)argv
                            count: (int)argc
