@@ -9,7 +9,7 @@
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
-   version 3 of the License, or (at your option) any later version.
+   version 2 of the License, or (at your option) any later version.
    
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -46,14 +46,14 @@ extern "C" {
 + (id) setWithObjects: (id)firstObject, ...;
 #if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 + (id) setWithObjects: (id*)objects
-		count: (unsigned)count;
+		count: (NSUInteger)count;
 #endif
 + (id) setWithSet: (NSSet*)aSet;
 
 - (NSArray*) allObjects;
 - (id) anyObject;
 - (BOOL) containsObject: (id)anObject;
-- (unsigned) count;
+- (NSUInteger) count;
 - (NSString*) description;
 - (NSString*) descriptionWithLocale: (NSDictionary*)locale;
 
@@ -61,7 +61,7 @@ extern "C" {
 - (id) initWithArray: (NSArray*)other;
 - (id) initWithObjects: (id)firstObject, ...;
 - (id) initWithObjects: (id*)objects
-		 count: (unsigned)count;
+		 count: (NSUInteger)count;
 - (id) initWithSet: (NSSet*)other;
 - (id) initWithSet: (NSSet*)other copyItems: (BOOL)flag;
 
@@ -78,15 +78,20 @@ extern "C" {
 - (id) member: (id)anObject;
 - (NSEnumerator*) objectEnumerator;
 
+#if OS_API_VERSION(100500,GS_API_LATEST) 
+- (NSSet *) setByAddingObject: (id)anObject;
+- (NSSet *) setByAddingObjectsFromSet: (NSSet *)other;
+- (NSSet *) setByAddingObjectsFromArray: (NSArray *)other;
+#endif
 @end
 
 @interface NSMutableSet: NSSet
 
-+ (id) setWithCapacity: (unsigned)numItems;
++ (id) setWithCapacity: (NSUInteger)numItems;
 
 - (void) addObject: (id)anObject;
 - (void) addObjectsFromArray: (NSArray*)array;
-- (id) initWithCapacity: (unsigned)numItems;
+- (id) initWithCapacity: (NSUInteger)numItems;
 - (void) intersectSet: (NSSet*)other;
 - (void) minusSet: (NSSet*)other;
 - (void) removeAllObjects;
@@ -99,7 +104,7 @@ extern "C" {
 
 @interface NSCountedSet : NSMutableSet
 
-- (unsigned int) countForObject: (id)anObject;
+- (NSUInteger) countForObject: (id)anObject;
 
 @end
 
@@ -120,7 +125,7 @@ extern "C" {
  *   been added once - and are therefore simply wasting space.
  * </p>
  */
-- (void) purge: (int)level;
+- (void) purge: (NSInteger)level;
 
 /**
  * <p>
@@ -170,13 +175,13 @@ id	GSUnique(id anObject);
  * set by removing any objec whose count is less than or equal to that given.
  *
  */
-void	GSUPurge(unsigned count);
+void	GSUPurge(NSUInteger count);
 
 /*
  * GSUSet() can be used to artificially set the count for a particular object
  * Setting the count to zero will remove the object from the global set.
  */
-id	GSUSet(id anObject, unsigned count);
+id	GSUSet(id anObject, NSUInteger count);
 
 #endif	/* GS_API_NONE */
 
