@@ -7,7 +7,7 @@
    This file is part of the GNUstep Library.
    
    This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
+   modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.
    
@@ -16,18 +16,23 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.
    
-   You should have received a copy of the GNU Library General Public
+   You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free
-   Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
-   MA 02111 USA.
+   Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02111 USA.
 */
 
-#ifndef _NSURL_h__
-#define _NSURL_h__
+#ifndef __NSURL_h_GNUSTEP_BASE_INCLUDE
+#define __NSURL_h_GNUSTEP_BASE_INCLUDE
+#import	<GNUstepBase/GSVersionMacros.h>
 
-#include <Foundation/NSURLHandle.h>
+#import	<Foundation/NSURLHandle.h>
 
-#ifndef	STRICT_OPENSTEP
+#if	defined(__cplusplus)
+extern "C" {
+#endif
+
+#if	OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 
 @class NSNumber;
 
@@ -112,6 +117,17 @@ GS_EXPORT NSString* const NSURLFileScheme;
   resourceDidFailLoadingWithReason: (NSString*)reason;
 @end
 
+#endif	/* GS_API_MACOSX */
+
+@interface NSURL (GSCategories)
+/** Returns the full path for this URL including any trailing slash.
+ */
+- (NSString*) fullPath;
+@end
+
+#if	defined(__cplusplus)
+}
 #endif
 
-#endif //_NSUrl_h__
+#endif	/* __NSURL_h_GNUSTEP_BASE_INCLUDE */
+
