@@ -9,7 +9,7 @@
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
-   version 3 of the License, or (at your option) any later version.
+   version 2 of the License, or (at your option) any later version.
    
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -128,13 +128,14 @@ GS_EXPORT NSString * const GSHTTPPropertyPasswordKey;
 }
 </example>
  */
-typedef enum
+enum
 {
   NSURLHandleNotLoaded = 0,
   NSURLHandleLoadSucceeded,
   NSURLHandleLoadInProgress,
   NSURLHandleLoadFailed
-} NSURLHandleStatus;
+};
+typedef NSUInteger NSURLHandleStatus;
 
 /**
  * A protocol to which clients of a handle must conform in order to
