@@ -80,7 +80,7 @@ extern NSString * const NSURLAuthenticationMethodHTTPDigest;
  * within the host, for others it may be nil.
  */
 - (id) initWithHost: (NSString *)host
-	       port: (int)port
+	       port: (NSInteger)port
 	   protocol: (NSString *)protocol
 	      realm: (NSString *)realm
 authenticationMethod: (NSString *)authenticationMethod;
@@ -91,7 +91,7 @@ authenticationMethod: (NSString *)authenticationMethod;
  * host and a protocol.
  */
 - (id) initWithProxyHost: (NSString *)host
-		    port: (int)port
+		    port: (NSInteger)port
 		    type: (NSString *)type
 		   realm: (NSString *)realm
     authenticationMethod: (NSString *)authenticationMethod;
@@ -105,7 +105,7 @@ authenticationMethod: (NSString *)authenticationMethod;
 /**
  * Returns the port set for this receiver or zero if none was set.
  */
-- (int) port;
+- (NSInteger) port;
 
 /**
  * Returns the protocol of the receiver or nil if it is a proxy.
