@@ -331,7 +331,7 @@ GS_EXPORT NSString* const GSLocale;
  * and returns its integer value or 0 if it is not representable
  * as an integer.
  */
-- (int) integerForKey: (NSString*)defaultName;
+- (NSInteger) integerForKey: (NSString*)defaultName;
 
 /**
  * Looks up a value for a specified default using.
@@ -381,13 +381,14 @@ GS_EXPORT NSString* const GSLocale;
  * Calls -setObject:forKey: to make the change by storing an intege
  * [NSNumber] instance.
  */
-- (void) setInteger: (int)value forKey: (NSString*)defaultName;
+- (void) setInteger: (NSInteger)value forKey: (NSString*)defaultName;
 
 /**
- * Sets an object value for defaultName in the application domain.<br />
+ * Sets a copy of an object value for defaultName in the
+ * application domain.<br />
  * The defaultName must be a non-empty string.<br />
- * The value must be an instance of one of the [NSString-propertyList]
- * classes.<br />
+ * The value to be copied into the domain must be an instance
+ * of one of the [NSString-propertyList] classes.<br />
  * <p>Causes a NSUserDefaultsDidChangeNotification to be posted
  * if this is the first change to a persistent-domain since the
  * last -synchronize.
