@@ -79,7 +79,6 @@ static	NSDictionary	*blank;
 {
   NSMutableString	*_textChars;
   NSMutableArray	*_infoArray;
-  NSString		*_textProxy;
 }
 
 - (id) initWithString: (NSString*)aString
@@ -593,11 +592,7 @@ SANITY();
 
 - (NSString*) string
 {
-  if (_textProxy == nil)
-    {
-      _textProxy = RETAIN([_textChars immutableProxy]);
-    }
-  return _textProxy;
+  return AUTORELEASE([_textChars copy]);
 }
 
 - (NSDictionary*) attributesAtIndex: (unsigned)index
@@ -887,7 +882,6 @@ SANITY();
 
 - (void) dealloc
 {
-  TEST_RELEASE(_textProxy);
   RELEASE(_textChars);
   RELEASE(_infoArray);
   [super dealloc];
