@@ -266,32 +266,11 @@ IMP gs_objc_msg_forward (SEL sel)
    * in the NSInvocation if the stack is changed before the
    * invocation is used.
    */
-#if MFRAME_STRUCT_BYREF
-  for (i = 0; i < ((cifframe_t *)_cframe)->nargs; i++)
-    {
-      const char *t = _info[i+1].type;
-
-      if (*t == _C_STRUCT_B || *t == _C_UNION_B || *t == _C_ARY_B)
-	{
-          /* Fix up some of the values. Do this on all processors that pass
-             structs by reference.
-             Is there an automatic way to determine this? */
-	  memcpy(((cifframe_t *)_cframe)->values[i], *(void **)vals[i],
-		 ((cifframe_t *)_cframe)->arg_types[i]->size);
-	}
-      else
-	{
-	  memcpy(((cifframe_t *)_cframe)->values[i], vals[i],
-		 ((cifframe_t *)_cframe)->arg_types[i]->size);
-	}
-    }
-#else
   for (i = 0; i < ((cifframe_t *)_cframe)->nargs; i++)
     {
       memcpy(((cifframe_t *)_cframe)->values[i], vals[i],
              ((cifframe_t *)_cframe)->arg_types[i]->size);
     }
-#endif
   _retval = retp;
   return self;
 }
