@@ -1096,8 +1096,20 @@ NSString * const GSSOCKSRecvAddr = @"GSSOCKSRecvAddr";
 
       if (fstat(desc, &sbuf) < 0)
 	{
+#if	defined(__MINGW32__)
+	  /* On windows, an fstat will fail if the descriptor is a pipe
+	   * or socket, so we simply mark the descriptor as not being a
+	   * standard file.
+	   */
+	  isStandardFile = NO;
+#else
+	  /* This should never happen on unix.  If it does, we have somehow
+	   * ended up with a bad descriptor.
+	   */
           NSLog(@"unable to get status of descriptor %d - %@",
 	    desc, [NSError _last]);
+	  isStandardFile = NO;
+#endif
 	}
       else
 	{
