@@ -409,6 +409,14 @@ static gnutls_anon_client_credentials_t anoncred;
               output: (GSSocketOutputStream*)o
 {
   NSString      *proto = [i propertyForKey: NSStreamSocketSecurityLevelKey];
+  BOOL		server = NO;
+
+/* FIXME
+  if ([[o propertyForKey: NSStreamSocketCertificateServerKey] boolValue] == YES)
+    {
+      server = YES;
+    }
+ */
 
   if (GSDebugSet(@"NSStream") == YES)
     {
@@ -421,6 +429,7 @@ static gnutls_anon_client_credentials_t anoncred;
 
   if ([[o propertyForKey: NSStreamSocketSecurityLevelKey] isEqual: proto] == NO)
     {
+      NSLog(@"NSStreamSocketSecurityLevel on input stream does not match output stream");
       DESTROY(self);
       return nil;
     }
@@ -433,7 +442,7 @@ static gnutls_anon_client_credentials_t anoncred;
   else if ([proto isEqualToString: NSStreamSocketSecurityLevelSSLv2] == YES)
     {
       proto = NSStreamSocketSecurityLevelSSLv2;
-      GSOnceMLog(@"NSStreamSocketSecurityLevelTLSv1 is insecure ..."
+      GSOnceMLog(@"NSStreamSocketSecurityLevelTLSv2 is insecure ..."
         @" not implemented");
       DESTROY(self);
       return nil;
@@ -470,7 +479,15 @@ static gnutls_anon_client_credentials_t anoncred;
 
   /* Initialise session and set default priorities foir key exchange.
    */
-  gnutls_init (&session, GNUTLS_CLIENT);
+  if (server)
+    {
+      gnutls_init (&session, GNUTLS_SERVER);
+      /* FIXME ... need to set up DH information and key/certificate. */
+    }
+  else
+    {
+      gnutls_init (&session, GNUTLS_CLIENT);
+    }
   gnutls_set_default_priority (session);
 
   if ([proto isEqualToString: NSStreamSocketSecurityLevelTLSv1] == YES)
