@@ -28,7 +28,7 @@
 
 
    <title>NSBundle class reference</title>
-   $Date: 2009-03-01 10:39:09 -0700 (Sun, 01 Mar 2009) $ $Revision: 28013 $
+   $Date: 2009-05-22 18:16:24 +0100 (Fri, 22 May 2009) $ $Revision: 28292 $
 */
 
 #include "config.h"
@@ -320,7 +320,7 @@ bundle_object_name(NSString *path, NSString* executable)
   path = [path stringByAppendingPathComponent: gnustep_target_dir];
   path1 = [path stringByAppendingPathComponent: name];
   path = [path stringByAppendingPathComponent: library_combo];
-  path2 = [path stringByAppendingPathComponent: executable];
+  path2 = [path stringByAppendingPathComponent: name];
 
   if ([mgr isReadableFileAtPath: path2] == YES)
     return path2;
@@ -328,7 +328,24 @@ bundle_object_name(NSString *path, NSString* executable)
     return path1;
   else if ([mgr isReadableFileAtPath: path0] == YES)
     return path0;
-  return path2;
+#if defined(__MINGW32__)
+  /* If we couldn't find the binary, and we are on windows, and the name
+   * has no path extension, then let's try looking for a dll.
+   */
+  if ([name pathExtension] == nil)
+    {
+      if ([mgr isReadableFileAtPath:
+	[path2 stringByAppendingPathExtension: @"dll"]] == YES)
+	return [path2 stringByAppendingPathExtension: @"dll"];
+      else if ([mgr isReadableFileAtPath:
+	[path1 stringByAppendingPathExtension: @"dll"]] == YES)
+	return [path1 stringByAppendingPathExtension: @"dll"];
+      else if ([mgr isReadableFileAtPath:
+	[path0 stringByAppendingPathExtension: @"dll"]] == YES)
+	return [path0 stringByAppendingPathExtension: @"dll"];
+    }
+#endif
+  return path0;
 }
 
 /* Construct a path from components */
