@@ -23,7 +23,7 @@
    Boston, MA 02111 USA.
 
    <title>NSCharacterSet class reference</title>
-   $Date: 2008-11-17 06:45:32 -0700 (Mon, 17 Nov 2008) $ $Revision: 27080 $
+   $Date: 2009-08-12 09:39:07 +0100 (Wed, 12 Aug 2009) $ $Revision: 28455 $
 */
 
 #include "config.h"
@@ -41,8 +41,8 @@
 #include "Foundation/NSData.h"
 #include "Foundation/NSDebug.h"
 
-//#define	GNUSTEP_INDEX_CHARSET	1
-#undef	GNUSTEP_INDEX_CHARSET
+#define	GNUSTEP_INDEX_CHARSET	1
+//#undef	GNUSTEP_INDEX_CHARSET
 
 #include "NSCharacterSetData.h"
 
