@@ -26,7 +26,7 @@
    Boston, MA 02111 USA.
 
    <title>NSConnection class reference</title>
-   $Date: 2009-03-09 09:11:51 -0600 (Mon, 09 Mar 2009) $ $Revision: 28054 $
+   $Date: 2009-08-31 08:47:44 +0100 (Mon, 31 Aug 2009) $ $Revision: 28579 $
    */
 
 #import "config.h"
@@ -37,6 +37,7 @@
 #import "Foundation/NSEnumerator.h"
 #import "GNUstepBase/preface.h"
 #import "GNUstepBase/GSLock.h"
+#import "Foundation/NSDebug.h"
 
 /*
  *	Setup for inline operation of pointer map tables.
@@ -799,8 +800,8 @@ static NSLock	*cached_proxies_gate = nil;
 
 - (NSString*) description
 {
-  return [NSString stringWithFormat: @"%@ recv: 0x%x send 0x%x",
-    [super description], (uintptr_t)[self receivePort], (uintptr_t)[self sendPort]];
+  return [NSString stringWithFormat: @"%@ recv: %@ send %@",
+    [super description], [self receivePort], [self sendPort]];
 }
 
 /**
@@ -1904,6 +1905,7 @@ static void retDecoder(DOContext *ctxt)
     }
 }
 
+#if !defined(USE_FFCALL) && !defined(USE_LIBFFI)
 static void retEncoder (DOContext *ctxt)
 {
   switch (*ctxt->type)
@@ -1928,6 +1930,7 @@ static void retEncoder (DOContext *ctxt)
       [ctxt->encoder encodeValueOfObjCType: ctxt->type at: ctxt->datum];
     }
 }
+#endif
 
 /*
  * NSDistantObject's -forward:: method calls this to send the message
@@ -1937,6 +1940,7 @@ static void retEncoder (DOContext *ctxt)
 		    selector: (SEL)sel
                     argFrame: (arglist_t)argframe
 {
+#if !defined(USE_FFCALL) && !defined(USE_LIBFFI)
   BOOL		outParams;
   BOOL		needsResponse;
   const char	*type;
@@ -2071,6 +2075,13 @@ static void retEncoder (DOContext *ctxt)
       NSAssert(ctxt.decoder == nil, NSInternalInconsistencyException);
     }
   return retframe;
+#else
+  /* If we've got to here then something has gone badly wrong.  Most likely a
+   * mismatch between NSDistantObject and NSConnection implementations.
+   */
+  NSAssert(NO, @"Legacy forwardForProxy:selector:argFrame: method called when compiled with fcall/ffi."); 
+  return 0; // Not reached.
+#endif //!defined(USE_FFCALL) && !defined(USE_LIBFFI)
 }
 
 /*
@@ -2870,15 +2881,22 @@ static void callEncoder (DOContext *ctxt)
   NSTimeInterval	last_interval = 0.0001;
   NSTimeInterval	delay_interval = last_interval;
   NSDate		*delay_date = nil;
-  NSRunLoop		*runLoop = GSRunLoopForThread(nil);
+  NSRunLoop		*runLoop;
   BOOL			isLocked = NO;
 
+  if (_isValid == NO)
+    {
+      [NSException raise: NSObjectInaccessibleException
+		  format: @"Connection has been invalidated"];
+    }
+
   /*
    * If we have sent out a request on a run loop that we don't already
    * know about, it must be on a new thread - so if we have multipleThreads
    * enabled, we must add the run loop of the new thread so that we can
    * get the reply in this thread.
    */
+  runLoop = GSRunLoopForThread(nil);
   if ([_runLoops indexOfObjectIdenticalTo: runLoop] == NSNotFound)
     {
       if (_multipleThreads == YES)
