@@ -23,7 +23,7 @@
    Boston, MA 02111 USA.
 
    <title>NSDistantObject class reference</title>
-   $Date: 2009-01-12 11:36:37 -0700 (Mon, 12 Jan 2009) $ $Revision: 27581 $
+   $Date: 2009-06-15 08:13:11 +0100 (Mon, 15 Jun 2009) $ $Revision: 28352 $
    */
 
 #include "config.h"
@@ -443,6 +443,24 @@ enum proxyLocation
 {
   return _connection;
 }
+/**
+ * NSProxy subclasses must override -init or an exception will be thrown.  This
+ * calls the forwarding mechanism to invoke -init on the remote object.
+ */
+- (id) init
+{
+  NSMethodSignature	*sig;
+  NSInvocation		*inv;
+  id			ret;
+
+  sig = [self methodSignatureForSelector: _cmd];
+  inv = [NSInvocation invocationWithMethodSignature: sig];
+  [inv setTarget: self];
+  [inv setSelector: _cmd];
+  [self forwardInvocation: inv];
+  [inv getReturnValue: &ret];
+  return ret;
+}
 
 - (void) dealloc
 {
