@@ -34,7 +34,7 @@
    Boston, MA 02111 USA.
 
    <title>NSFileManager class reference</title>
-   $Date: 2009-04-27 05:52:44 -0600 (Mon, 27 Apr 2009) $ $Revision: 28253 $
+   $Date: 2009-08-25 12:13:00 +0100 (Tue, 25 Aug 2009) $ $Revision: 28540 $
 */
 
 #define _FILE_OFFSET_BITS 64
@@ -392,7 +392,6 @@ static NSStringEncoding	defaultEncoding;
 - (BOOL) changeFileAttributes: (NSDictionary*)attributes atPath: (NSString*)path
 {
   const _CHAR	*lpath = 0;
-  NSNumber	*tmpNum;
   unsigned long	num;
   NSString	*str;
   NSDate	*date;
@@ -411,7 +410,8 @@ static NSStringEncoding	defaultEncoding;
     }
   else
     {
-      tmpNum = [attributes fileOwnerAccountID];
+      NSNumber	*tmpNum = [attributes fileOwnerAccountID];
+
       num = tmpNum ? [tmpNum unsignedLongValue] : NSNotFound;
     }
   if (num != NSNotFound)
@@ -474,7 +474,8 @@ static NSStringEncoding	defaultEncoding;
     }
   else
     {
-      tmpNum = [attributes fileGroupOwnerAccountID];
+      NSNumber	*tmpNum = [attributes fileGroupOwnerAccountID];
+
       num = tmpNum ? [tmpNum unsignedLongValue] : NSNotFound;
     }
   if (num != NSNotFound)
@@ -1924,11 +1925,6 @@ static NSStringEncoding	defaultEncoding;
   return [path lastPathComponent];
 }
 
-/**
- * Returns an enumerator which can be used to return each item with
- * the directory at path in turn.<br />
- * The enumeration is recursive ... following all nested subdirectories.
- */
 - (NSDirectoryEnumerator*) enumeratorAtPath: (NSString*)path
 {
   return AUTORELEASE([[NSDirectoryEnumerator alloc]
@@ -2021,11 +2017,15 @@ static NSStringEncoding	defaultEncoding;
 #if	defined(__MINGW32__)
 - (const GSNativeChar*) fileSystemRepresentationWithPath: (NSString*)path
 {
+  if (path != nil && [path rangeOfString: @"/"].length > 0)
+    {
+      path = [path stringByReplacingString: @"/" withString: @"\\"];
+    }
   return
     (const GSNativeChar*)[path cStringUsingEncoding: NSUnicodeStringEncoding];
 }
 - (NSString*) stringWithFileSystemRepresentation: (const GSNativeChar*)string
-					  length: (unsigned int)len
+					  length: (NSUInteger)len
 {
   return [NSString stringWithCharacters: string length: len];
 }
@@ -2076,16 +2076,6 @@ static inline void gsedRelease(GSEnumeratedDirectory X)
 #include "GNUstepBase/GSIArray.h"
 
 
-/**
- *  <p>This is a subclass of <code>NSEnumerator</code> which provides a full
- *  listing of all the files beneath a directory and its subdirectories.
- *  Instances can be obtained through [NSFileManager-enumeratorAtPath:],
- *  or through an initializer in this class.  (For compatibility with OS X,
- *  use the <code>NSFileManager</code> method.)</p>
- *
- *  <p>This implementation is optimized and performance should be comparable
- *  to the speed of standard Unix tools for large directories.</p>
- */
 @implementation NSDirectoryEnumerator
 /*
  * The Objective-C interface hides a traditional C implementation.
@@ -2100,8 +2090,6 @@ static inline void gsedRelease(GSEnumeratedDirectory X)
     }
 }
 
-// Initializing
-
 /**
  *  Initialize instance to enumerate contents at path, which should be a
  *  directory and can be specified in relative or absolute, and may include
