@@ -21,7 +21,7 @@
    Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02111 USA.
 
-   $Date: 2009-04-16 03:07:13 -0600 (Thu, 16 Apr 2009) $ $Revision: 28223 $
+   $Date: 2009-05-23 07:00:45 +0100 (Sat, 23 May 2009) $ $Revision: 28295 $
 */
 
 #include "GNUstepBase/preface.h"
@@ -473,11 +473,10 @@ replacementForClass(Class c)
             }
 
           /*
-           * A setter must take three arguments (self, _cmd, value)
-           * and return nothing.
+           * A setter must take three arguments (self, _cmd, value).
+           * The return value (if any) is ignored.
            */
-          if (*[sig methodReturnType] != _C_VOID
-            || [sig numberOfArguments] != 3)
+          if ([sig numberOfArguments] != 3)
             {
               continue;	// Not a valid setter method.
             }
