@@ -37,13 +37,23 @@
 /*
  *	Setup for inline operation of pointer map tables.
  */
-#define	GSI_MAP_RETAIN_KEY(M, X)	RETAIN(X.obj)	
-#define	GSI_MAP_RELEASE_KEY(M, X)	RELEASE(X.obj)
 #define	GSI_MAP_RETAIN_VAL(M, X)	
 #define	GSI_MAP_RELEASE_VAL(M, X)	
 #define	GSI_MAP_HASH(M, X)	((X).uint)
 #define	GSI_MAP_EQUAL(M, X,Y)	((X).ptr == (Y).ptr)
 #undef	GSI_MAP_NOCLEAN
+#if	GS_WITH_GC
+#include	<gc_typed.h>
+static GC_descr	nodeDesc;	// Type descriptor for map node.
+#define	GSI_MAP_NODES(M, X) \
+(GSIMapNode)GC_calloc_explicitly_typed(X, sizeof(GSIMapNode_t), nodeDesc)
+#define	GSI_MAP_RETAIN_KEY(M, X)
+#define	GSI_MAP_RELEASE_KEY(M, X)
+#else
+#define	GSI_MAP_RETAIN_KEY(M, X)	RETAIN(X.obj)	
+#define	GSI_MAP_RELEASE_KEY(M, X)	RELEASE(X.obj)
+#endif
+
 
 #include "GNUstepBase/GSIMap.h"
 
@@ -67,7 +77,7 @@ static Class	NSScannerClass = 0;
 static SEL	scanFloatSel;
 static SEL	scanStringSel;
 static SEL	scannerSel;
-static BOOL	(*scanFloatImp)(NSScanner*, SEL, float*);
+static BOOL	(*scanFloatImp)(NSScanner*, SEL, CGFloat*);
 static BOOL	(*scanStringImp)(NSScanner*, SEL, NSString*, NSString**);
 static id 	(*scannerImp)(Class, SEL, NSString*);
 
@@ -78,10 +88,17 @@ setupCache(void)
     {
       NSStringClass = [NSString class];
       NSScannerClass = [NSScanner class];
-      scanFloatSel = @selector(scanFloat:);
+      if (sizeof(CGFloat) == sizeof(double))
+        {
+          scanFloatSel = @selector(scanDouble:);
+        }
+      else
+        {
+          scanFloatSel = @selector(scanFloat:);
+        }
       scanStringSel = @selector(scanString:intoString:);
       scannerSel = @selector(scannerWithString:);
-      scanFloatImp = (BOOL (*)(NSScanner*, SEL, float*))
+      scanFloatImp = (BOOL (*)(NSScanner*, SEL, CGFloat*))
 	[NSScannerClass instanceMethodForSelector: scanFloatSel];
       scanStringImp = (BOOL (*)(NSScanner*, SEL, NSString*, NSString**))
 	[NSScannerClass instanceMethodForSelector: scanStringSel];
@@ -464,6 +481,16 @@ static NSDictionary *makeReference(unsigned ref)
 
 + (void) initialize
 {
+  GSMakeWeakPointer(self, "delegate");
+
+#if	GS_WITH_GC
+  /* We create a typed memory descriptor for map nodes.
+   */
+  GC_word	w[GC_BITMAP_SIZE(GSIMapNode_t)] = {0};
+  GC_set_bit(w, GC_WORD_OFFSET(GSIMapNode_t, key));
+  GC_set_bit(w, GC_WORD_OFFSET(GSIMapNode_t, value));
+  nodeDesc = GC_make_descriptor(w, GC_WORD_LEN(GSIMapNode_t));
+#endif
   if (globalClassMap == 0)
     {
       globalClassMap =
@@ -526,7 +553,7 @@ static NSDictionary *makeReference(unsigned ref)
 }
 
 - (void) encodeArrayOfObjCType: (const char*)aType
-			 count: (unsigned)aCount
+			 count: (NSUInteger)aCount
 			    at: (const void*)address
 {
   id	o;
@@ -545,7 +572,7 @@ static NSDictionary *makeReference(unsigned ref)
   [_enc setObject: [NSNumber  numberWithBool: aBool] forKey: aKey];
 }
 
-- (void) encodeBytes: (const uint8_t*)aPointer length: (unsigned)length forKey: (NSString*)aKey
+- (void) encodeBytes: (const uint8_t*)aPointer length: (NSUInteger)length forKey: (NSString*)aKey
 {
   CHECKKEY
 
@@ -622,22 +649,22 @@ static NSDictionary *makeReference(unsigned ref)
 
 - (void) encodePoint: (NSPoint)p
 {
-  [self encodeValueOfObjCType: @encode(float) at: &p.x];
-  [self encodeValueOfObjCType: @encode(float) at: &p.y];
+  [self encodeValueOfObjCType: @encode(CGFloat) at: &p.x];
+  [self encodeValueOfObjCType: @encode(CGFloat) at: &p.y];
 }
 
 - (void) encodeRect: (NSRect)r
 {
-  [self encodeValueOfObjCType: @encode(float) at: &r.origin.x];
-  [self encodeValueOfObjCType: @encode(float) at: &r.origin.y];
-  [self encodeValueOfObjCType: @encode(float) at: &r.size.width];
-  [self encodeValueOfObjCType: @encode(float) at: &r.size.height];
+  [self encodeValueOfObjCType: @encode(CGFloat) at: &r.origin.x];
+  [self encodeValueOfObjCType: @encode(CGFloat) at: &r.origin.y];
+  [self encodeValueOfObjCType: @encode(CGFloat) at: &r.size.width];
+  [self encodeValueOfObjCType: @encode(CGFloat) at: &r.size.height];
 }
 
 - (void) encodeSize: (NSSize)s
 {
-  [self encodeValueOfObjCType: @encode(float) at: &s.width];
-  [self encodeValueOfObjCType: @encode(float) at: &s.height];
+  [self encodeValueOfObjCType: @encode(CGFloat) at: &s.width];
+  [self encodeValueOfObjCType: @encode(CGFloat) at: &s.height];
 }
 
 - (void) encodeValueOfObjCType: (const char*)type
@@ -675,17 +702,17 @@ static NSDictionary *makeReference(unsigned ref)
 	return;
 
       case _C_CHR:
-	o = [NSNumber numberWithInt: (int)*(char*)address];
+	o = [NSNumber numberWithInt: (NSInteger)*(char*)address];
 	[_enc setObject: o forKey: aKey];
 	return;
 
       case _C_UCHR:
-	o = [NSNumber numberWithInt: (int)*(unsigned char*)address];
+	o = [NSNumber numberWithInt: (NSInteger)*(unsigned char*)address];
 	[_enc setObject: o forKey: aKey];
 	return;
 
       case _C_SHT:
-	o = [NSNumber numberWithInt: (int)*(short*)address];
+	o = [NSNumber numberWithInt: (NSInteger)*(short*)address];
 	[_enc setObject: o forKey: aKey];
 	return;
 
@@ -695,12 +722,12 @@ static NSDictionary *makeReference(unsigned ref)
 	return;
 
       case _C_INT:
-	o = [NSNumber numberWithInt: *(int*)address];
+	o = [NSNumber numberWithInt: *(NSInteger*)address];
 	[_enc setObject: o forKey: aKey];
 	return;
 
       case _C_UINT:
-	o = [NSNumber numberWithUnsignedInt: *(unsigned int*)address];
+	o = [NSNumber numberWithUnsignedInt: *(NSUInteger*)address];
 	[_enc setObject: o forKey: aKey];
 	return;
 
@@ -807,7 +834,12 @@ static NSDictionary *makeReference(unsigned ref)
       /*
        *	Set up map tables.
        */
+#if	GS_WITH_GC
+      _cIdMap = (GSIMapTable)NSAllocateCollectable(sizeof(GSIMapTable_t)*5,
+	NSScannedOption);
+#else
       _cIdMap = (GSIMapTable)NSZoneMalloc(zone, sizeof(GSIMapTable_t)*5);
+#endif
       _uIdMap = &_cIdMap[1];
       _repMap = &_cIdMap[2];
       GSIMapInitWithZoneAndCapacity(_cIdMap, zone, 10);
