@@ -37,8 +37,13 @@
 /*
  *      Setup for inline operation of arrays.
  */
-#define GSI_ARRAY_RETAIN(A, X)	RETAIN((X).obj)
-#define GSI_ARRAY_RELEASE(A, X)	RELEASE((X).obj)
+#if	GS_WITH_GC
+#define GSI_ARRAY_RETAIN(A, X)
+#define GSI_ARRAY_RELEASE(A, X)
+#else
+#define GSI_ARRAY_RETAIN(A, X)	[(X).obj retain]
+#define GSI_ARRAY_RELEASE(A, X)	[(X).obj release]
+#endif
 #define GSI_ARRAY_TYPES GSUNION_OBJ
 
 
@@ -59,7 +64,7 @@
 NSString * const NSInvalidUnarchiveOperationException
   = @"NSInvalidUnarchiveOperationException";
 
-static NSMapTable	globalClassMap = 0;
+static NSMapTable	*globalClassMap = 0;
 
 #define	GETVAL \
   id		o; \
@@ -274,6 +279,8 @@ static NSMapTable	globalClassMap = 0;
 
 + (void) initialize
 {
+  GSMakeWeakPointer(self, "delegate");
+
   if (globalClassMap == 0)
     {
       globalClassMap =
@@ -417,7 +424,7 @@ static NSMapTable	globalClassMap = 0;
 }
 
 - (const uint8_t*) decodeBytesForKey: (NSString*)aKey
-		      returnedLength: (unsigned*)length
+		      returnedLength: (NSUInteger*)length
 {
   NSString	*oldKey = aKey;
   GETVAL
@@ -607,8 +614,8 @@ static NSMapTable	globalClassMap = 0;
 {
   NSPoint	p;
 
-  [self decodeValueOfObjCType: @encode(float) at: &p.x];
-  [self decodeValueOfObjCType: @encode(float) at: &p.y];
+  [self decodeValueOfObjCType: @encode(CGFloat) at: &p.x];
+  [self decodeValueOfObjCType: @encode(CGFloat) at: &p.y];
   return p;
 }
 
@@ -616,10 +623,10 @@ static NSMapTable	globalClassMap = 0;
 {
   NSRect	r;
 
-  [self decodeValueOfObjCType: @encode(float) at: &r.origin.x];
-  [self decodeValueOfObjCType: @encode(float) at: &r.origin.y];
-  [self decodeValueOfObjCType: @encode(float) at: &r.size.width];
-  [self decodeValueOfObjCType: @encode(float) at: &r.size.height];
+  [self decodeValueOfObjCType: @encode(CGFloat) at: &r.origin.x];
+  [self decodeValueOfObjCType: @encode(CGFloat) at: &r.origin.y];
+  [self decodeValueOfObjCType: @encode(CGFloat) at: &r.size.width];
+  [self decodeValueOfObjCType: @encode(CGFloat) at: &r.size.height];
   return r;
 }
 
@@ -627,8 +634,8 @@ static NSMapTable	globalClassMap = 0;
 {
   NSSize	s;
 
-  [self decodeValueOfObjCType: @encode(float) at: &s.width];
-  [self decodeValueOfObjCType: @encode(float) at: &s.height];
+  [self decodeValueOfObjCType: @encode(CGFloat) at: &s.width];
+  [self decodeValueOfObjCType: @encode(CGFloat) at: &s.height];
   return s;
 }
 
@@ -773,13 +780,6 @@ static NSMapTable	globalClassMap = 0;
 	errorDescription: &error];
       if (_archive == nil)
 	{
-#ifndef	HAVE_LIBXML
-	  if (format == NSPropertyListXMLFormat_v1_0)
-	    {
-	      NSLog(@"Unable to parse XML archive as the base "
-		@"library was not configured with libxml2 support.");
-	    }
-#endif
 	  DESTROY(self);
 	}
       else
@@ -787,7 +787,7 @@ static NSMapTable	globalClassMap = 0;
 	  unsigned	count;
 	  unsigned	i;
 
-	  RETAIN(_archive);
+	  IF_NO_GC(RETAIN(_archive);)
 	  _archiverClass = [_archive objectForKey: @"$archiver"];
 	  _version = [_archive objectForKey: @"$version"];
 
@@ -796,7 +796,11 @@ static NSMapTable	globalClassMap = 0;
 
 	  _clsMap = NSCreateMapTable(NSObjectMapKeyCallBacks,
 	    NSNonOwnedPointerMapValueCallBacks, 0);
+#if	GS_WITH_GC
+	  _objMap = NSAllocateCollectable(sizeof(GSIArray_t), NSScannedOption);
+#else
 	  _objMap = NSZoneMalloc(_zone, sizeof(GSIArray_t));
+#endif
 	  count = [_objects count];
 	  GSIArrayInitWithZoneAndCapacity(_objMap, _zone, count);
 	  // Add marker for nil object
