@@ -1335,9 +1335,13 @@ typedef	struct {
 - (NSString*) description
 {
   NSString	*desc;
+  NSArray	*names;
 
-  desc = [NSString stringWithFormat: @"<NSMessagePort %p with name %s>",
-	   self, [name bytes]];
+  names = [[NSMessagePortNameServer sharedInstance] namesForPort: self];
+  desc = [NSString stringWithFormat:
+    @"<%s %p %@ with file name %s>",
+    GSClassNameFromObject(self), self,
+    ([names count] == 0) ? (id)@"<un-named>" : (id)names, [name bytes]];
   return desc;
 }
 
