@@ -22,7 +22,7 @@
    Boston, MA 02111 USA.
 
    <title>NSObject class reference</title>
-   $Date: 2009-05-04 14:07:56 -0600 (Mon, 04 May 2009) $ $Revision: 28268 $
+   $Date: 2009-08-15 22:44:21 +0100 (Sat, 15 Aug 2009) $ $Revision: 28462 $
    */
 
 /* On some versions of mingw we need to work around bad function declarations
@@ -65,6 +65,9 @@
 #ifdef	HAVE_SYS_SIGNAL_H
 #include	<sys/signal.h>
 #endif
+#ifdef __FreeBSD__
+#include <fenv.h>
+#endif
 
 #include "GSPrivate.h"
 
@@ -219,7 +222,7 @@ typedef int32_t volatile *gsatomic_t;
 #define	GSAtomicDecrement(X)	InterlockedDecrement((LONG volatile*)X)
 
 
-#elif defined(USE_ATOMIC_BUILDINS) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 1))
+#elif defined(__llvm__) || (defined(USE_ATOMIC_BUILDINS) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 1)))
 /* Use the GCC atomic operations with recent GCC versions */
 
 typedef int32_t volatile *gsatomic_t;
@@ -292,6 +295,30 @@ GSAtomicDecrement(gsatomic_t X)
   return *X;
 }
 
+#elif defined(__m68k__)
+
+typedef int32_t volatile *gsatomic_t;
+
+#define	GSATOMICREAD(X)	(*(X))
+
+static __inline__ int
+GSAtomicIncrement(gsatomic_t X)
+{
+  __asm__ __volatile__ (
+    "addq%.l %#1, %0"
+    :"=m" (*X));
+    return *X;
+}
+
+static __inline__ int
+GSAtomicDecrement(gsatomic_t X)
+{
+  __asm__ __volatile__ (
+    "subq%.l %#1, %0"
+    :"=m" (*X));
+    return *X;
+}
+
 #endif
 
 #if	!defined(GSATOMICREAD)
@@ -665,12 +692,15 @@ GSPrivateSwizzle(id o, Class c)
 	}
       else if (GSIsFinalizable(c))
 	{
-	  /* New clas is finalizable, so we must register the instance
+	  /* New class is finalizable, so we must register the instance
 	   * for finalisation and do allocation acounting for it.
 	   */
 	  AADD(c, o);
 	  GC_REGISTER_FINALIZER (o, GSFinalize, NULL, NULL, NULL);
 	}
+#else
+      AREM(o->class_pointer, o);
+      AADD(c, o);
 #endif	/* GS_WITH_GC */
       o->class_pointer = c;
     }
@@ -944,14 +974,7 @@ GSGarbageCollectorLog(char *msg, GC_word arg)
       // Manipulate the FPU to add the exception mask. (Fixes SIGFPE
       // problems on *BSD)
       // Note this only works on x86
-
-      {
-	volatile short cw;
-
-	__asm__ volatile ("fstcw (%0)" : : "g" (&cw));
-	cw |= 1; /* Mask 'invalid' exception */
-	__asm__ volatile ("fldcw (%0)" : : "g" (&cw));
-      }
+      fedisableexcept(FE_INVALID);
 #endif
 
 
