@@ -47,11 +47,6 @@
 // For pow()
 #include <math.h>
 
-#define	NIMP	  [NSException raise: NSGenericException \
-  format: @"%s(%s) has not implemented %s",\
-  GSClassNameFromObject(self), GSObjCIsInstance(self) ? "instance" : "class",\
-  GSNameFromSelector(_cmd)]
-
 @interface GSPredicateScanner : NSScanner
 {
   NSEnumerator	*_args;		// Not retained.
@@ -189,13 +184,13 @@
               case 'c':
                 ptr++;
                 [arr addObject: [NSNumber numberWithChar:
-                  (char)va_arg(args, int)]];
+                  (char)va_arg(args, NSInteger)]];
                 break;
 
               case 'C':
                 ptr++;
                 [arr addObject: [NSNumber numberWithShort:
-                  (short)va_arg(args, int)]];
+                  (short)va_arg(args, NSInteger)]];
                 break;
 
               case 'd':
@@ -203,7 +198,7 @@
               case 'i':
                 ptr++;
                 [arr addObject: [NSNumber numberWithInt:
-                  va_arg(args, int)]];
+                  va_arg(args, NSInteger)]];
                 break;
 
               case 'o':
@@ -214,7 +209,7 @@
               case 'X':
                 ptr++;
                 [arr addObject: [NSNumber numberWithUnsignedInt:
-                  va_arg(args, unsigned int)]];
+                  va_arg(args, NSUInteger)]];
                 break;
 
               case 'e':
@@ -235,12 +230,12 @@
                     if (c == 'i')
                       {
                         [arr addObject: [NSNumber numberWithShort:
-                          (short)va_arg(args, int)]];
+                          (short)va_arg(args, NSInteger)]];
                       }
                     if (c == 'u')
                       {
                         [arr addObject: [NSNumber numberWithUnsignedShort:
-                          (unsigned short)va_arg(args, int)]];
+                          (unsigned short)va_arg(args, NSInteger)]];
                       }
                   }
                 break;
@@ -621,7 +616,7 @@
                               rightExpression: (NSExpression *)right
                                      modifier: (NSComparisonPredicateModifier)modifier
                                          type: (NSPredicateOperatorType)type
-                                      options: (unsigned)opts
+                                      options: (NSUInteger)opts
 {
   return AUTORELEASE([[self alloc] initWithLeftExpression: left 
                                           rightExpression: right
@@ -648,7 +643,7 @@
               rightExpression: (NSExpression *)right
                      modifier: (NSComparisonPredicateModifier)modifier
                          type: (NSPredicateOperatorType)type
-                      options: (unsigned)opts
+                      options: (NSUInteger)opts
 {
   if ((self = [super init]) != nil)
     {
@@ -683,7 +678,7 @@
   return _left;
 }
 
-- (unsigned) options
+- (NSUInteger) options
 {
   return _options;
 }
@@ -1534,6 +1529,48 @@
 
 @end
 
+@implementation NSSet (NSPredicate)
+
+- (NSSet *) filteredSetUsingPredicate: (NSPredicate *)predicate
+{
+  NSMutableSet	*result;
+  NSEnumerator	*e = [self objectEnumerator];
+  id		object;
+
+  result = [NSMutableSet setWithCapacity: [self count]];
+  while ((object = [e nextObject]) != nil)
+    {
+      if ([predicate evaluateWithObject: object] == YES)
+        {
+          [result addObject: object];  // passes filter
+        }
+    }
+  return [result makeImmutableCopyOnFail: NO];
+}
+
+@end
+
+@implementation NSMutableSet (NSPredicate)
+
+- (void) filterUsingPredicate: (NSPredicate *)predicate
+{
+  NSMutableSet	*rejected;
+  NSEnumerator	*e = [self objectEnumerator];
+  id		object;
+
+  rejected = [NSMutableSet setWithCapacity: [self count]];
+  while ((object = [e nextObject]) != nil)
+    {
+      if ([predicate evaluateWithObject: object] == NO)
+        {
+          [rejected addObject: object];
+        }
+    }
+  [self minusSet: rejected];
+}
+
+@end
+
 
 
 @implementation GSPredicateScanner
