@@ -23,7 +23,7 @@
    Boston, MA 02111 USA.
 
    <title>NSProcessInfo class reference</title>
-   $Date: 2009-02-23 13:42:32 -0700 (Mon, 23 Feb 2009) $ $Revision: 27962 $
+   $Date: 2009-07-04 12:28:34 +0100 (Sat, 04 Jul 2009) $ $Revision: 28378 $
 */
 
 /*************************************************************************
@@ -1445,6 +1445,11 @@ BOOL GSDebugSet(NSString *level)
 	  [[NSProcessInfo processInfo] debugSet];
 	}
       debugImp = [_debug_set methodForSelector: debugSel];
+      if (debugImp == 0)
+	{
+	  fprintf(stderr, "Unable to set up with [NSProcessInfo-debugSet]\n");
+	  return NO;
+	}
     }
   if ((*debugImp)(_debug_set, debugSel, level) == nil)
     {
