@@ -43,6 +43,7 @@
 #include "Foundation/NSConnection.h"
 #include "Foundation/NSDebug.h"
 
+#include "GSNetwork.h"
 #include "GSPortPrivate.h"
 #include "GSPrivate.h"
 
@@ -54,7 +55,6 @@
 
 #ifdef __MINGW32__
 #define close closesocket
-#define socklen_t	int
 #else
 #include <sys/param.h>		/* for MAXHOSTNAMELEN */
 #include <sys/types.h>
@@ -1802,19 +1802,15 @@ static Class		tcpPortClass;
 
 - (NSString*) description
 {
-  NSMutableString	*desc;
+  NSString	*desc;
+  NSArray	*names;
 
-  desc = [NSMutableString stringWithFormat: @"NSPort on host with details -\n"
-    @"%@\n", host];
-  if (address == nil)
-    {
-      [desc appendFormat: @"  IP address - any\n"];
-    }
-  else
-    {
-      [desc appendFormat: @"  IP address - %@\n", address];
-    }
-  [desc appendFormat: @"  TCP port - %d\n", portNum];
+  names = [[NSSocketPortNameServer sharedInstance] namesForPort: self];
+  desc = [NSString stringWithFormat:
+    @"<%s %p %@ on IP %@,%d>",
+    GSClassNameFromObject(self), self,
+    (([names count] == 0) ? (id)@"(<un-named>)" : (id)names), host,
+    ((address == nil) ? (id)@"any" : (id)address), portNum];
   return desc;
 }
 
@@ -1874,6 +1870,7 @@ static Class		tcpPortClass;
       if (handle->recvPort == recvSelf && handle->inReplyMode == NO)
 	{
 	  fds[(*count)++] = (uintptr_t)event;
+          NSDebugMLLog(@"NSPort", @"Add event %p", event);
 	}
     }
   NSEndMapTableEnumeration(&me);
@@ -2148,8 +2145,8 @@ static Class		tcpPortClass;
 #endif
   GSTcpHandle	*handle;
 
-  NSDebugMLLog(@"NSPort", @"received %s event on 0x%x",
-    type == ET_RPORT ? "read" : "write", self);
+  NSDebugMLLog(@"NSPort", @"received %s event %p on 0x%x",
+    type == ET_RPORT ? "read" : "write", extra, self);
 
 #if	defined(__MINGW32__)
   if (event == eventListener)
