@@ -24,7 +24,7 @@
    Boston, MA 02111 USA.
 
    <title>NSTimer class reference</title>
-   $Date: 2009-01-09 02:23:40 -0700 (Fri, 09 Jan 2009) $ $Revision: 27564 $
+   $Date: 2009-09-01 13:16:03 +0100 (Tue, 01 Sep 2009) $ $Revision: 28593 $
    */
 
 #include "config.h"
@@ -40,12 +40,16 @@
 static Class	NSDate_class;
 
 /**
- * An <code>NSTimer</code> provides a way to send a message at some time in
+ * <p>An <code>NSTimer</code> provides a way to send a message at some time in
  * the future, possibly repeating every time a fixed interval has passed. To
  * use a timer, you can either create one that will automatically be added to
  * the run loop in the current thread (using the -addTimer:forMode: method),
  * or you can create it without adding it then add it to an [NSRunLoop]
  * explicitly later.
+ * </p>
+ * <p>NB. You may not use -init or +new to create a timer, as the timer must
+ * be properly initialised to send an action after some interval.
+ * </p>
  */
 @implementation NSTimer
 
@@ -57,6 +61,14 @@ static Class	NSDate_class;
     }
 }
 
+/* For MacOS-X compatibility, this returns nil.
+ */
+- (id) init
+{
+  [self release];
+  return nil;
+}
+
 /**
  * <init />
  * Initialise the receive, a newly allocated NSTimer object.<br />
