@@ -614,7 +614,7 @@ static NSURLProtocol	*placeholder = nil;
   /* Perform a redirect if the path is empty.
    * As per MacOs-X documentation.
    */
-  if ([[[this->request URL] path] length] == 0)
+  if ([[[this->request URL] fullPath] length] == 0)
     {
       NSString		*s = [[this->request URL] absoluteString];
       NSURL		*url;
@@ -1058,7 +1058,7 @@ static NSURLProtocol	*placeholder = nil;
 		      auth = [authentication
 			authorizationForAuthentication: hdr
 			method: [this->request HTTPMethod]
-			path: [url path]];
+			path: [url fullPath]];
 		    }
 
 		  if (auth == nil)
@@ -1274,7 +1274,7 @@ static NSURLProtocol	*placeholder = nil;
 	      [m appendString: [this->request HTTPMethod]];
 	      [m appendString: @" "];
 	      u = [this->request URL];
-	      s = [u path];
+	      s = [u fullPath];
 	      if ([s hasPrefix: @"/"] == NO)
 	        {
 		  [m appendString: @"/"];
@@ -1305,7 +1305,21 @@ static NSURLProtocol	*placeholder = nil;
 		}
 	      if ([this->request valueForHTTPHeaderField: @"Host"] == nil)
 		{
-		  [m appendFormat: @"Host: %@\r\n", [u host]];
+		  id	p = [u port];
+		  id	h = [u host];
+
+		  if (h == nil)
+		    {
+		      h = @"";	// Must send an empty host header
+		    }
+		  if (p == nil)
+		    {
+		      [m appendFormat: @"Host: %@\r\n", h];
+		    }
+		  else
+		    {
+		      [m appendFormat: @"Host: %@:%@\r\n", h, p];
+		    }
 		}
 	      if (l >= 0 && [this->request
 	        valueForHTTPHeaderField: @"Content-Length"] == nil)
@@ -1678,7 +1692,7 @@ static NSURLProtocol	*placeholder = nil;
   NSURLResponse	*r;
   NSData	*data = [NSData data];	// no data
 
-  // we could pass different content depending on the [url path]
+  // we could pass different content depending on the url path
   r = [[NSURLResponse alloc] initWithURL: [this->request URL]
 				MIMEType: @"text/html"
 		   expectedContentLength: 0
