@@ -98,7 +98,7 @@ static const NSMapTableValueCallBacks WatcherMapValueCallBacks =
 #ifdef	HAVE_POLL_F
   if (pollfds != 0)
     {
-      objc_free(pollfds);
+      NSZoneFree(NSDefaultMallocZone(), pollfds);
     }
 #endif
   [super dealloc];
@@ -175,16 +175,27 @@ static const NSMapTableValueCallBacks WatcherMapValueCallBacks =
   self = [super init];
   if (self != nil)
     {
-      NSZone	*z = [self zone];
+      NSZone	*z;
 
       mode = [theMode copy];
       extra = e;
+#if	GS_WITH_GC
+      z = (NSZone*)1;
+      performers = NSAllocateCollectable(sizeof(GSIArray_t), NSScannedOption);
+      timers = NSAllocateCollectable(sizeof(GSIArray_t), NSScannedOption);
+      watchers = NSAllocateCollectable(sizeof(GSIArray_t), NSScannedOption);
+      _trigger = NSAllocateCollectable(sizeof(GSIArray_t), NSScannedOption);
+#else
+      z = [self zone];
       performers = NSZoneMalloc(z, sizeof(GSIArray_t));
-      GSIArrayInitWithZoneAndCapacity(performers, z, 8);
       timers = NSZoneMalloc(z, sizeof(GSIArray_t));
-      GSIArrayInitWithZoneAndCapacity(timers, z, 8);
       watchers = NSZoneMalloc(z, sizeof(GSIArray_t));
+      _trigger = NSZoneMalloc(z, sizeof(GSIArray_t));
+#endif
+      GSIArrayInitWithZoneAndCapacity(performers, z, 8);
+      GSIArrayInitWithZoneAndCapacity(timers, z, 8);
       GSIArrayInitWithZoneAndCapacity(watchers, z, 8);
+      GSIArrayInitWithZoneAndCapacity(_trigger, z, 8);
 
       _efdMap = NSCreateMapTable (NSIntMapKeyCallBacks,
 				      WatcherMapValueCallBacks, 0);
@@ -192,8 +203,6 @@ static const NSMapTableValueCallBacks WatcherMapValueCallBacks =
 				      WatcherMapValueCallBacks, 0);
       _wfdMap = NSCreateMapTable (NSIntMapKeyCallBacks,
 				      WatcherMapValueCallBacks, 0);
-      _trigger = NSZoneMalloc(z, sizeof(GSIArray_t));
-      GSIArrayInitWithZoneAndCapacity(_trigger, z, 8);
     }
   return self;
 }
@@ -213,11 +222,23 @@ static void setPollfd(int fd, int event, GSRunLoopCtxt *ctxt)
       pe->limit = fd + 1;
       if (pe->index == 0)
 	{
-	  pe->index = objc_malloc(pe->limit * sizeof(*(pe->index)));
+#if	GS_WITH_GC
+	  pe->index
+	    = NSAllocateCollectable(pe->limit * sizeof(*(pe->index)), 0);
+#else
+	  pe->index = NSZoneMalloc(NSDefaultMallocZone(),
+	    pe->limit * sizeof(*(pe->index)));
+#endif
 	}
       else
 	{
-	  pe->index = objc_realloc(pe->index, pe->limit * sizeof(*(pe->index)));
+#if	GS_WITH_GC
+	  pe->index = NSReallocateCollectable(pe->index,
+	    pe->limit * sizeof(*(pe->index)), 0);
+#else
+	  pe->index = NSZoneRealloc(NSDefaultMallocZone(),
+	    pe->index, pe->limit * sizeof(*(pe->index)));
+#endif
 	}
       do
 	{
@@ -231,8 +252,13 @@ static void setPollfd(int fd, int event, GSRunLoopCtxt *ctxt)
       if (ctxt->pollfds_count >= ctxt->pollfds_capacity)
 	{
 	  ctxt->pollfds_capacity += 8;
-	  pollfds =
-	    objc_realloc(pollfds, ctxt->pollfds_capacity * sizeof (*pollfds));
+#if	GS_WITH_GC
+	  pollfds = NSReallocateCollectable(pollfds,
+	    ctxt->pollfds_capacity * sizeof (*pollfds), 0);
+#else
+	  pollfds = NSZoneRealloc(NSDefaultMallocZone(),
+	    pollfds, ctxt->pollfds_capacity * sizeof (*pollfds));
+#endif
 	  ctxt->pollfds = pollfds;
 	}
       index = ctxt->pollfds_count++;
@@ -281,11 +307,23 @@ static void setPollfd(int fd, int event, GSRunLoopCtxt *ctxt)
       pollfds_capacity = i + 2;
       if (pollfds == 0)
 	{
-	  pollfds = objc_malloc(pollfds_capacity * sizeof(*pollfds));
+#if	GS_WITH_GC
+	  pollfds
+	    = NSAllocateCollectable(pollfds_capacity * sizeof(*pollfds), 0);
+#else
+	  pollfds = NSZoneMalloc(NSDefaultMallocZone(),
+	    pollfds_capacity * sizeof(*pollfds));
+#endif
 	}
       else
 	{
-	  pollfds = objc_realloc(pollfds, pollfds_capacity * sizeof(*pollfds));
+#if	GS_WITH_GC
+	  pollfds = NSReallocateCollectable(pollfds,
+	    pollfds_capacity * sizeof(*pollfds), 0);
+#else
+	  pollfds = NSZoneRealloc(NSDefaultMallocZone(),
+	    pollfds, pollfds_capacity * sizeof(*pollfds));
+#endif
 	}
     }
   pollfds_count = 0;
@@ -571,6 +609,7 @@ static void setPollfd(int fd, int event, GSRunLoopCtxt *ctxt)
 	    {
               if (fd == threadInfo->inputFd)
                 {
+	          NSDebugMLLog(@"NSRunLoop", @"Fire perform on thread");
                   [threadInfo fire];
                   watcher = nil;
                 }
@@ -625,6 +664,27 @@ static void setPollfd(int fd, int event, GSRunLoopCtxt *ctxt)
   return YES;
 }
 
++ (BOOL) awakenedBefore: (NSDate*)when
+{
+  GSRunLoopThreadInfo   *threadInfo = GSRunLoopInfoForThread(nil);
+  NSTimeInterval	ti = (when == nil) ? 0.0 : [when timeIntervalSinceNow];
+  int			milliseconds = (ti <= 0.0) ? 0 : (int)(ti*1000);
+  struct pollfd		pollfds;
+
+  /* Watch for signals from other threads.
+   */
+  pollfds.fd = threadInfo->inputFd;
+  pollfds.events = POLLIN;
+  pollfds.revents = 0;
+  if (poll(&pollfds, 1, milliseconds) == 1)
+    {
+      NSDebugMLLog(@"NSRunLoop", @"Fire perform on thread");
+      [threadInfo fire];
+      return YES;
+    }
+  return NO;
+}
+
 #else
 
 - (BOOL) pollUntil: (int)milliseconds within: (NSArray*)contexts
@@ -683,7 +743,7 @@ static void setPollfd(int fd, int event, GSRunLoopCtxt *ctxt)
   NSResetMapTable(_wfdMap);
   GSIArrayRemoveAllItems(_trigger);
 
-  /* Watch for signals from otyher threads.
+  /* Watch for signals from other threads.
    */
   fd = threadInfo->inputFd;
   if (fd > fdEnd)
@@ -950,6 +1010,7 @@ static void setPollfd(int fd, int event, GSRunLoopCtxt *ctxt)
 
           if (fdIndex == threadInfo->inputFd)
             {
+	      NSDebugMLLog(@"NSRunLoop", @"Fire perform on thread");
               [threadInfo fire];
               watcher = nil;
             }
@@ -1001,5 +1062,31 @@ static void setPollfd(int fd, int event, GSRunLoopCtxt *ctxt)
   return YES;
 }
 
++ (BOOL) awakenedBefore: (NSDate*)when
+{
+  GSRunLoopThreadInfo   *threadInfo = GSRunLoopInfoForThread(nil);
+  NSTimeInterval	ti = (when == nil) ? 0.0 : [when timeIntervalSinceNow];
+  int			milliseconds = (ti <= 0.0) ? 0 : (int)(ti*1000);
+  struct timeval	timeout;
+  fd_set 		read_fds;	// Mask for read-ready fds.
+  fd_set 		exception_fds;	// Mask for exception fds.
+  fd_set 		write_fds;	// Mask for write-ready fds.
+
+  memset(&exception_fds, '\0', sizeof(exception_fds));
+  memset(&read_fds, '\0', sizeof(read_fds));
+  memset(&write_fds, '\0', sizeof(write_fds));
+  timeout.tv_sec = milliseconds/1000;
+  timeout.tv_usec = (milliseconds - 1000 * timeout.tv_sec) * 1000;
+  FD_SET (threadInfo->inputFd, &read_fds);
+  if (select (threadInfo->inputFd, &read_fds, &write_fds,
+    &exception_fds, &timeout) > 0)
+    {
+      NSDebugMLLog(@"NSRunLoop", @"Fire perform on thread");
+      [threadInfo fire];
+      return YES;
+    }
+  return NO;
+}
+
 #endif
 @end
