@@ -872,7 +872,11 @@ again:
 	}
       else if ((errno = GetLastError()) != ERROR_IO_PENDING)
 	{
-	  NSLog(@"unable to write to mailslot '%@' - %@",
+	  /* This is probably an end of file
+	   * eg. when the process at the other end has terminated.
+	   */
+	  NSDebugMLog(@"NSMessagePort",
+	    @"unable to write to mailslot '%@' - %@",
 	    this->name, [NSError _last]);
 	  [self invalidate];
 	}
